@@ -21,7 +21,7 @@
 set -e
 set -x
 
-requires nbdkit --exit-with-parent --version
+requires $NBDKIT --exit-with-parent --version
 requires cmp /dev/null /dev/null
 
 pidfile=copy-nbd-to-null.pid
@@ -29,17 +29,7 @@ file=copy-nbd-to-null.file
 sock=$(mktemp -u /tmp/libnbd-test-copy.XXXXXX)
 cleanup_fn rm -f $pidfile $file $sock
 
-nbdkit --exit-with-parent -f -v -P $pidfile -U $sock pattern size=10M &
-# Wait for the pidfile to appear.
-for i in {1..60}; do
-    if test -f $pidfile; then
-        break
-    fi
-    sleep 1
-done
-if ! test -f $pidfile; then
-    echo "$0: nbdkit did not start up"
-    exit 1
-fi
+$NBDKIT --exit-with-parent -f -v -P $pidfile -U $sock pattern size=10M &
+wait_for_pidfile $NBDKIT $pidfile
 
 $VG nbdcopy "nbd+unix:///?socket=$sock" null:
