@@ -21,8 +21,8 @@
 set -e
 set -x
 
-requires nbdkit --exit-with-parent --version
+requires $NBDKIT --exit-with-parent --version
 requires dd if=/dev/null of=/dev/null
 
 dd if=/dev/zero bs=1M count=10 |
-    $VG nbdcopy -- - [ nbdkit --exit-with-parent -v memory size=10M ]
+    $VG nbdcopy -- - [ $NBDKIT --exit-with-parent -v memory size=10M ]
