@@ -21,23 +21,13 @@
 set -e
 set -x
 
-requires nbdkit --exit-with-parent --version
+requires $NBDKIT --exit-with-parent --version
 
 pidfile=copy-zero-to-nbd.pid
 sock=$(mktemp -u /tmp/libnbd-test-copy.XXXXXX)
 cleanup_fn rm -f $pidfile $sock
 
-nbdkit --exit-with-parent -f -v -P $pidfile -U $sock memory size=10M &
-# Wait for the pidfile to appear.
-for i in {1..60}; do
-    if test -f $pidfile; then
-        break
-    fi
-    sleep 1
-done
-if ! test -f $pidfile; then
-    echo "$0: nbdkit did not start up"
-    exit 1
-fi
+$NBDKIT --exit-with-parent -f -v -P $pidfile -U $sock memory size=10M &
+wait_for_pidfile $NBDKIT $pidfile
 
 $VG nbdcopy -p /dev/null "nbd+unix:///?socket=$sock"
