@@ -1,5 +1,5 @@
 /* NBD client library in userspace.
- * Copyright (C) 2020-2022 Red Hat Inc.
+ * Copyright Red Hat
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -116,7 +116,7 @@ struct extent {
   uint64_t length;
   bool zero;
 };
-DEFINE_VECTOR_TYPE(extent_list, struct extent);
+DEFINE_VECTOR_TYPE (extent_list, struct extent);
 
 /* The operations struct hides some of the differences between local
  * file, NBD and pipes from the copying code.
@@ -228,7 +228,7 @@ extern void asynch_notify_read_write_not_supported (struct rw *rw,
 
 extern bool allocated;
 extern unsigned connections;
-extern bool destination_is_zero;
+extern bool target_is_zero;
 extern bool extents;
 extern bool flush;
 extern unsigned max_requests;
