@@ -25,8 +25,8 @@ set -x
 
 requires_fuse
 requires dd --version
-requires nbdkit --version
-requires nbdkit memory --version
+requires $NBDKIT --version
+requires $NBDKIT memory --version
 
 # Difficult to arrange for this test to be run this test under
 # valgrind, so don't bother.
@@ -41,19 +41,8 @@ cleanup_fn fusermount3 -u $mp
 cleanup_fn rm -rf $mp $pidfile
 
 mkdir $mp
-$VG nbdfuse -P $pidfile $mp [ nbdkit --exit-with-parent memory size=10M ] &
-
-# Wait for the pidfile to appear.
-for i in {1..60}; do
-    if test -f $pidfile; then
-        break
-    fi
-    sleep 1
-done
-if ! test -f $pidfile; then
-    echo "$0: nbdfuse PID file $pidfile was not created"
-    exit 1
-fi
+$VG nbdfuse -P $pidfile $mp [ $NBDKIT --exit-with-parent memory size=10M ] &
+wait_for_pidfile nbdfuse $pidfile
 
 ls -al $mp
 
