@@ -26,8 +26,8 @@ set -x
 requires_fuse
 requires fallocate --version
 requires dd --version
-requires nbdkit --version
-requires nbdkit sh --version
+requires $NBDKIT --version
+requires $NBDKIT sh --version
 
 # Difficult to arrange for this test to be run this test under
 # valgrind, so don't bother.
@@ -45,9 +45,9 @@ cleanup_fn rm -rf $mp $pidfile $out
 mkdir $mp
 
 export mp pidfile out prog="$0"
-nbdkit -U - \
-       sh - \
-       --run '
+$NBDKIT -U - \
+        sh - \
+        --run '
 set -x
 
 # Run nbdfuse and connect to the nbdkit server.
