@@ -1,5 +1,5 @@
 /* nbd client library in userspace: state machine
- * Copyright (C) 2013-2019 Red Hat Inc.
+ * Copyright Red Hat
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -36,6 +36,8 @@
 #include <sys/types.h>
 #include <sys/socket.h>
 
+extern char **environ;
+
 /* Disable Nagle's algorithm on the socket, but don't fail. */
 static void
 disable_nagle (int sock)
@@ -45,6 +47,21 @@ disable_nagle (int sock)
   setsockopt (sock, IPPROTO_TCP, TCP_NODELAY, &flag, sizeof flag);
 }
 
+/* Disable SIGPIPE on FreeBSD & MacOS.
+ *
+ * Does nothing on other platforms, but if those platforms have
+ * MSG_NOSIGNAL then we will set that when writing.  (FreeBSD has both.)
+ */
+static void
+disable_sigpipe (int sock)
+{
+#ifdef SO_NOSIGPIPE
+  const int flag = 1;
+
+  setsockopt (sock, SOL_SOCKET, SO_NOSIGPIPE, &flag, sizeof flag);
+#endif
+}
+
 STATE_MACHINE {
  CONNECT.START:
   sa_family_t family;
@@ -52,7 +69,7 @@ STATE_MACHINE {
 
   assert (!h->sock);
   family = h->connaddr.ss_family;
-  fd = socket (family, SOCK_STREAM|SOCK_NONBLOCK|SOCK_CLOEXEC, 0);
+  fd = nbd_internal_socket (family, SOCK_STREAM, 0, true);
   if (fd == -1) {
     SET_NEXT_STATE (%.DEAD);
     set_error (errno, "socket");
@@ -65,8 +82,9 @@ STATE_MACHINE {
   }
 
   disable_nagle (fd);
+  disable_sigpipe (fd);
 
-  r = connect (fd, (struct sockaddr *) &h->connaddr, h->connaddrlen);
+  r = connect (fd, (struct sockaddr *)&h->connaddr, h->connaddrlen);
   if (r == 0 || (r == -1 && errno == EINPROGRESS))
     return 0;
   assert (r == -1);
@@ -137,7 +155,7 @@ STATE_MACHINE {
   r = getaddrinfo (h->hostname, h->port, &h->hints, &h->result);
   if (r != 0) {
     SET_NEXT_STATE (%^START);
-    set_error (0, "getaddrinfo: %s:%s: %s",
+    set_error (0, "getaddrinfo: hostname \"%s\" port \"%s\": %s",
                h->hostname, h->port, gai_strerror (r));
     return -1;
   }
@@ -162,9 +180,10 @@ STATE_MACHINE {
     return -1;
   }
 
-  fd = socket (h->rp->ai_family,
-               h->rp->ai_socktype|SOCK_NONBLOCK|SOCK_CLOEXEC,
-               h->rp->ai_protocol);
+  fd = nbd_internal_socket (h->rp->ai_family,
+                            h->rp->ai_socktype,
+                            h->rp->ai_protocol,
+                            true);
   if (fd == -1) {
     SET_NEXT_STATE (%NEXT_ADDRESS);
     return 0;
@@ -176,6 +195,7 @@ STATE_MACHINE {
   }
 
   disable_nagle (fd);
+  disable_sigpipe (fd);
 
   if (connect (fd, h->rp->ai_addr, h->rp->ai_addrlen) == -1) {
     if (errno != EINPROGRESS) {
@@ -220,39 +240,87 @@ STATE_MACHINE {
   return 0;
 
  CONNECT_COMMAND.START:
+  enum state next;
+  bool parentfd_transferred;
   int sv[2];
-  pid_t pid;
   int flags;
+  struct socket *sock;
+  struct execvpe execvpe_ctx;
+  pid_t pid;
 
   assert (!h->sock);
   assert (h->argv.ptr);
   assert (h->argv.ptr[0]);
-  if (socketpair (AF_UNIX, SOCK_STREAM|SOCK_CLOEXEC, 0, sv) == -1) {
-    SET_NEXT_STATE (%.DEAD);
+
+  next = %.DEAD;
+  parentfd_transferred = false;
+
+  if (nbd_internal_socketpair (AF_UNIX, SOCK_STREAM, 0, sv) == -1) {
     set_error (errno, "socketpair");
-    return 0;
+    goto done;
+  }
+
+  /* A process is effectively in an unusable state if any of STDIN_FILENO
+   * (fd#0), STDOUT_FILENO (fd#1) and STDERR_FILENO (fd#2) don't exist. If they
+   * exist however, then the socket pair created above will not intersect with
+   * the fd set { 0, 1, 2 }. This is relevant for the child-side dup2() logic
+   * below.
+   */
+  assert (sv[0] > STDERR_FILENO);
+  assert (sv[1] > STDERR_FILENO);
+
+  /* Only the parent-side end of the socket pair must be set to non-blocking,
+   * because the child may not be expecting a non-blocking socket.
+   */
+  flags = fcntl (sv[0], F_GETFL, 0);
+  if (flags == -1 ||
+      fcntl (sv[0], F_SETFL, flags|O_NONBLOCK) == -1) {
+    set_error (errno, "fcntl");
+    goto close_socket_pair;
+  }
+
+  sock = nbd_internal_socket_create (sv[0]);
+  if (!sock)
+    /* nbd_internal_socket_create() calls set_error() internally */
+    goto close_socket_pair;
+  parentfd_transferred = true;
+
+  if (nbd_internal_execvpe_init (&execvpe_ctx, h->argv.ptr[0], h->argv.len) ==
+      -1) {
+    set_error (errno, "nbd_internal_execvpe_init");
+    goto close_high_level_socket;
   }
 
   pid = fork ();
   if (pid == -1) {
-    SET_NEXT_STATE (%.DEAD);
     set_error (errno, "fork");
-    close (sv[0]);
-    close (sv[1]);
-    return 0;
+    goto uninit_execvpe;
   }
+
   if (pid == 0) {         /* child - run command */
-    close (0);
-    close (1);
-    close (sv[0]);
-    dup2 (sv[1], 0);
-    dup2 (sv[1], 1);
-    close (sv[1]);
+    if (close (sv[0]) == -1) {
+      nbd_internal_fork_safe_perror ("close");
+      _exit (126);
+    }
+    if (dup2 (sv[1], STDIN_FILENO) == -1 ||
+        dup2 (sv[1], STDOUT_FILENO) == -1) {
+      nbd_internal_fork_safe_perror ("dup2");
+      _exit (126);
+    }
+    NBD_INTERNAL_FORK_SAFE_ASSERT (sv[1] != STDIN_FILENO);
+    NBD_INTERNAL_FORK_SAFE_ASSERT (sv[1] != STDOUT_FILENO);
+    if (close (sv[1]) == -1) {
+      nbd_internal_fork_safe_perror ("close");
+      _exit (126);
+    }
 
     /* Restore SIGPIPE back to SIG_DFL. */
-    signal (SIGPIPE, SIG_DFL);
+    if (signal (SIGPIPE, SIG_DFL) == SIG_ERR) {
+      nbd_internal_fork_safe_perror ("signal");
+      _exit (126);
+    }
 
-    execvp (h->argv.ptr[0], h->argv.ptr);
+    (void)nbd_internal_fork_safe_execvpe (&execvpe_ctx, &h->argv, environ);
     nbd_internal_fork_safe_perror (h->argv.ptr[0]);
     if (errno == ENOENT)
       _exit (127);
@@ -260,33 +328,32 @@ STATE_MACHINE {
       _exit (126);
   }
 
-  /* Parent. */
-  close (sv[1]);
-
+  /* Parent -- we're done; commit. */
   h->pid = pid;
-
-  /* The socket must be set to non-blocking only in the parent,
-   * because the child may not be expecting a non-blocking socket.
-   */
-  flags = fcntl (sv[0], F_GETFL, 0);
-  if (flags == -1 ||
-      fcntl (sv[0], F_SETFL, flags|O_NONBLOCK) == -1) {
-    SET_NEXT_STATE (%.DEAD);
-    close (sv[0]);
-    return 0;
-  }
-
-  h->sock = nbd_internal_socket_create (sv[0]);
-  if (!h->sock) {
-    SET_NEXT_STATE (%.DEAD);
-    close (sv[0]);
-    return 0;
-  }
+  h->sock = sock;
 
   /* The sockets are connected already, we can jump directly to
    * receiving the server magic.
    */
-  SET_NEXT_STATE (%^MAGIC.START);
+  next = %^MAGIC.START;
+
+  /* fall through, for releasing the temporaries */
+
+uninit_execvpe:
+  nbd_internal_execvpe_uninit (&execvpe_ctx);
+
+close_high_level_socket:
+  if (next == %.DEAD)
+    sock->ops->close (sock);
+
+close_socket_pair:
+  assert (next == %.DEAD || parentfd_transferred);
+  if (!parentfd_transferred)
+    close (sv[0]);
+  close (sv[1]);
+
+done:
+  SET_NEXT_STATE (next);
   return 0;
 
 } /* END STATE MACHINE */
