@@ -59,6 +59,7 @@ nbd_create (void)
     set_error (errno, "calloc");
     goto error1;
   }
+  h->magic = NBD_HANDLE_MAGIC;
 
   if (asprintf (&h->hname, "nbd%d", hnums++) == -1) {
     set_error (errno, "asprintf");
@@ -128,6 +129,8 @@ nbd_close (struct nbd_handle *h)
   if (h == NULL)
     return;
 
+  assert (h->magic == NBD_HANDLE_MAGIC);
+
   debug (h, "closing handle");
 
   /* Free user callbacks first. */
@@ -172,6 +175,11 @@ nbd_close (struct nbd_handle *h)
   string_vector_empty (&h->request_meta_contexts);
   free (h->hname);
   pthread_mutex_destroy (&h->lock);
+
+  /* Although we are about to free the handle, set the h->magic field
+   * to something invalid so we can catch use-after-free.
+   */
+  h->magic = 0xdeaddead;
   free (h);
 }
 
