@@ -17,14 +17,11 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *)
 
+open Ocaml_test_config
+
 open Printf
 
-let script =
-  try
-    let srcdir = Sys.getenv "srcdir" in
-    sprintf "%s/../../tests/opt-list.sh" srcdir
-  with
-    Not_found -> failwith "error: srcdir is not defined"
+let script = sprintf "%s/../../tests/opt-list.sh" srcdir
 
 let exports = ref []
 let f user_data name desc =
@@ -39,7 +36,7 @@ let conn mode body expect =
   NBD.set_opt_mode nbd true;
   let mode = sprintf "mode=%d" mode in
   NBD.connect_command nbd
-                      ["nbdkit"; "-s"; "--exit-with-parent"; "-v";
+                      [nbdkit; "-s"; "--exit-with-parent"; "-v";
                        "sh"; script; mode];
   body nbd;
   assert (!exports = expect);
