@@ -17,22 +17,15 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *)
 
+open Ocaml_test_config
+
 open Printf
 
-(* NB: OCaml 4.08 has endian functions in the Bytes module which
- * would make this loop much simpler.
- *)
 let expected =
   let b = Bytes.create 512 in
   for i = 0 to 512/8-1 do
-    let i64 = ref (Int64.of_int (i*8)) in
-    for j = 0 to 7 do
-      let c = Int64.shift_right_logical !i64 56 in
-      let c = Int64.to_int c in
-      let c = Char.chr c in
-      Bytes.unsafe_set b (i*8+j) c;
-      i64 := Int64.shift_left !i64 8
-    done
+    let i64 = Int64.of_int (i*8) in
+    bytes_set_int64_be b (i*8) i64
   done;
   b
 
@@ -51,7 +44,7 @@ let f user_data buf2 offset s err =
 let () =
   let nbd = NBD.create () in
   NBD.connect_command nbd
-                      ["nbdkit"; "-s"; "--exit-with-parent"; "-v";
+                      [nbdkit; "-s"; "--exit-with-parent"; "-v";
                        "pattern"; "size=512"];
   let buf = Bytes.create 512 in
 
