@@ -17,6 +17,8 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *)
 
+open Ocaml_test_config
+
 open Unix
 
 let () =
@@ -32,7 +34,7 @@ let () =
   close_out chan;
 
   let nbd = NBD.create () in
-  NBD.connect_command nbd ["nbdkit"; "-s"; "--exit-with-parent"; "-v";
+  NBD.connect_command nbd [nbdkit; "-s"; "--exit-with-parent"; "-v";
                            "file"; datafile];
   let flags = let open NBD.CMD_FLAG in [FUA] in
   NBD.pwrite nbd buf1 0_L ~flags;
