@@ -23,24 +23,29 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <ctype.h>
 #include <fcntl.h>
 #include <unistd.h>
 #include <time.h>
 
 #include <libnbd.h>
 
+#include "pick-a-port.h"
 #include "requires.h"
 
-#ifdef NEEDS_UNIX_SOCKET
-#define UNIX_SOCKET tmp
-static char tmp[] = "/tmp/nbdXXXXXX";
+#ifdef DEFINE_STR_AS_UNIX_SOCKET
+static char str[] = "/tmp/nbdXXXXXX";
 
 static void
 unlink_unix_socket (void)
 {
-  unlink (UNIX_SOCKET);
+  unlink (str);
 }
-#endif /* NEEDS_UNIX_SOCKET */
+#endif
+
+#ifdef DEFINE_STR_AS_PORT
+static char str[] = "12345";
+#endif
 
 static int compare_uris (const char *uri1, const char *uri2);
 
@@ -48,27 +53,25 @@ int
 main (int argc, char *argv[])
 {
   struct nbd_handle *nbd;
+  const char *s;
+  char *pidfile;
   pid_t pid;
   size_t i;
   char *get_uri;
-#ifdef NEEDS_UNIX_SOCKET
   char *uri;
-#else
-  const char *uri = URI;
-#endif
 
   /* If SERVER_PARAMS contains --tls-verify-peer we must make sure
    * that nbdkit supports that option.
    */
 #ifdef REQUIRES_NBDKIT_TLS_VERIFY_PEER
-  requires ("nbdkit --tls-verify-peer -U - null --run 'exit 0'");
+  requires (NBDKIT " --tls-verify-peer -U - null --run 'exit 0'");
 #endif
 
-#ifdef NEEDS_UNIX_SOCKET
-  int fd = mkstemp (UNIX_SOCKET);
+#ifdef DEFINE_STR_AS_UNIX_SOCKET
+  int fd = mkstemp (str);
   if (fd == -1 ||
       close (fd) == -1) {
-    perror (UNIX_SOCKET);
+    perror (str);
     exit (EXIT_FAILURE);
   }
   /* We have to remove the temporary file first, since we will create
@@ -76,15 +79,31 @@ main (int argc, char *argv[])
    */
   unlink_unix_socket ();
   atexit (unlink_unix_socket);
+#endif
 
-  /* uri = URI + UNIX_SOCKET */
-  if (asprintf (&uri, "%s%s", URI, UNIX_SOCKET) == -1) {
+#ifdef DEFINE_STR_AS_PORT
+  int port = pick_a_port ();
+  snprintf (str, sizeof str, "%d", port);
+#endif
+
+  if (asprintf (&uri, URI) == -1) {
     perror ("asprintf");
     exit (EXIT_FAILURE);
   }
-#endif
 
-  unlink (PIDFILE);
+  /* Generate a PID file (for nbdkit -P) derived from the basename of
+   * the current binary, which is unique for each test.
+   */
+  s = strrchr (argv[0], '/');
+  if (s) s++; else s = argv[0];
+  if (asprintf (&pidfile, "%s.pid", s) == -1) {
+    perror ("asprintf");
+    exit (EXIT_FAILURE);
+  }
+  if (strstr (pidfile, "connect") == NULL)
+    abort ();
+
+  unlink (pidfile);
 
   pid = fork ();
   if (pid == -1) {
@@ -92,10 +111,10 @@ main (int argc, char *argv[])
     exit (EXIT_FAILURE);
   }
   if (pid == 0) {
-    execlp ("nbdkit",
+    execlp (NBDKIT,
             "nbdkit", "-f", "-v", "--exit-with-parent",
 //          "-D", "nbdkit.tls.log=99",
-            "-P", PIDFILE,
+            "-P", pidfile,
             SERVER_PARAMS,
             "null", NULL);
     perror ("nbdkit");
@@ -104,11 +123,12 @@ main (int argc, char *argv[])
 
   /* Wait for nbdkit to start listening. */
   for (i = 0; i < 60; ++i) {
-    if (access (PIDFILE, F_OK) == 0)
+    if (access (pidfile, F_OK) == 0)
       break;
     sleep (1);
   }
-  unlink (PIDFILE);
+  unlink (pidfile);
+  free (pidfile);
 
   nbd = nbd_create ();
   if (nbd == NULL) {
@@ -158,12 +178,43 @@ main (int argc, char *argv[])
   }
 
   nbd_close (nbd);
-#ifdef NEEDS_UNIX_SOCKET
   free (uri);
-#endif
   exit (EXIT_SUCCESS);
 }
 
+#ifdef HAVE_STRCASESTR
+#define case_insensitive_substring(s1, s2) (strcasestr ((s1), (s2)) != NULL)
+#else
+static int
+case_insensitive_substring (const char *haystack, const char *needle)
+{
+  /* strcasestr was implemented first in GNU libc, and later added to
+   * FreeBSD and OpenBSD.  However it is not in POSIX so far.
+   *
+   * Don't use this as a general replacement for strcasestr.  It's not
+   * unicode safe, nor efficient, so only suitable for this test.
+   */
+  char *s1 = strdup (haystack);
+  char *s2 = strdup (needle);
+  size_t i, n;
+  int r;
+
+  if (!s1 || !s2) abort ();
+
+  n = strlen (s1);
+  for (i = 0; i < n; ++i)
+    s1[i] = tolower (s1[i]);
+  n = strlen (s2);
+  for (i = 0; i < n; ++i)
+    s2[i] = tolower (s2[i]);
+  r = strstr (s1, s2) != NULL;
+
+  free (s1);
+  free (s2);
+  return r;
+}
+#endif
+
 /* Naive comparison of two URIs, enough to get the tests to pass but
  * it does not take into account things like quoting.  The difference
  * between the URI we set and the one we read back is the order of
@@ -177,7 +228,7 @@ compare_uris (const char *uri1, const char *uri2)
 
   /* Compare the parts before the query fields. */
   n = strcspn (uri1, "?");
-  r = strncmp (uri1, uri2, n);
+  r = strncasecmp (uri1, uri2, n);
   if (r != 0) return r;
 
   if (strlen (uri1) == n)
@@ -195,7 +246,7 @@ compare_uris (const char *uri1, const char *uri2)
     n = strcspn (uri1, "&");
     q = strndup (uri1, n);
     if (q == NULL) { perror ("strndup"); exit (EXIT_FAILURE); }
-    if (strstr (uri2, q) != NULL)
+    if (case_insensitive_substring (uri2, q))
       r = 0;
     else {
       fprintf (stderr, "error: compare_uris: query string '%s' does not appear "
