@@ -60,7 +60,7 @@ main (int argc, char *argv[])
 {
   struct nbd_handle *nbd;
   const char *cmd[] = {
-    "nbdkit", "-s", "-v", "--exit-with-parent", "memory", "1048576", NULL
+    NBDKIT, "-s", "-v", "--exit-with-parent", "memory", "1048576", NULL
   };
   uint32_t strict;
 
