@@ -90,7 +90,7 @@ main (int argc, char *argv[])
 {
   struct nbd_handle *nbd;
   const char *cmd[] = {
-    "nbdkit", "-s", "-v", "--exit-with-parent",
+    NBDKIT, "-s", "-v", "--exit-with-parent",
     "memory", "1024",
     "--filter=blocksize-policy", "blocksize-minimum=512",
     "blocksize-error-policy=error",
@@ -100,7 +100,7 @@ main (int argc, char *argv[])
 
   progname = argv[0];
 
-  requires ("nbdkit --version --filter=blocksize-policy null");
+  requires (NBDKIT " --version --filter=blocksize-policy null");
 
   nbd = nbd_create ();
   if (nbd == NULL) {
